@@ -1,8 +1,9 @@
 use wasm_bindgen::{closure::Closure, JsCast};
 
+thread_local!(static WINDOW: web_sys::Window = web_sys::window().expect("no global `window` exists"));
 /// utility function which returns the Window element
 pub fn window() -> web_sys::Window {
-    web_sys::window().expect("no global `window` exists")
+    WINDOW.with(|window| window.clone())
 }
 
 /// utility function which returns the history api of the browser
@@ -29,11 +30,10 @@ pub(crate) fn request_animation_frame_for_closure(f: &Closure<dyn FnMut()>) {
         .expect("should register `requestAnimationFrame` OK");
 }
 
+thread_local!(static DOCUMENT: web_sys::Document = window().document().expect("should have a document on window"));
 /// provides access to the document element
 pub fn document() -> web_sys::Document {
-    window()
-        .document()
-        .expect("should have a document on window")
+    DOCUMENT.with(|document| document.clone())
 }
 
 /// provides access to the document body
